@@ -1,6 +1,6 @@
 <?
 session_start(); // session Ѵ.
-include_once "../include/print.ph";
+include_once "../include/print.php";
 parse_query_str();
 if ($mode == "login") {
   session_register("mysqlpass"); // Ѵ.
@@ -10,11 +10,11 @@ if ($mode == "login") {
   header("Location: auth.php?mode=first&langss=$langss");
 } elseif ($mode == "first") {
   session_destroy(); //  Ѵ
-  $langs[code] = ($langss == "ko") ? "ko" : "en";
+  $langs['code'] = ($langss == "ko") ? "ko" : "en";
 
-  $path[type] = "Install";
-  include "../include/lang.ph";
-  $str = str_replace("\n","\\n",$langs[first_acc]);
+  $path['type'] = "Install";
+  include "../include/lang.php";
+  $str = str_replace("\n","\\n",$langs['first_acc']);
   $nostr = str_replace("\n","<BR>\n",$str);
   echo "<script>\n" .
        "  alert('$str')\n" .
